@@ -46,7 +46,7 @@ class CachedData(object):
 
     def put(self, value):
         self.id = uuid1().hex
-        KVStore(config.host, self.name).set(self.id, value)
+        KVStore(config.host, self.name).set(self.id, value, serialize=False)
 
     def get(self, key):
         return KVStore(config.host, self.name).get(key)
